|Build Status| |Coverage Status| |Code Style|

AFFO Email Service
==================

============ =============================================
**Version**  1.0.3
**Web**      https://affo.io/
**Download** https://pypi.org/affoio/affo-email-service/
**Source**   https://github.com/affoio/affo-email-service/
**Keywords** python, email, service
============ =============================================

Installation
------------

::

   pip install affo-email-service

Tests
-----

To run the test suite execute the following command in package root
folder:

::

   python setup.py test

.. |Build Status| image:: https://travis-ci.org/affoio/affo-email-service.svg?branch=master
   :target: https://travis-ci.org/affoio/affo-email-service
.. |Coverage Status| image:: https://coveralls.io/repos/github/affoio/affo-email-service/badge.svg?branch=master
   :target: https://coveralls.io/github/affoio/affo-email-service?branch=master
.. |Code Style| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
